@@ -7,6 +7,7 @@ exploration, and test suites with time budgets and result aggregation.
 
 from __future__ import annotations
 
+import os
 import re
 import shutil
 import subprocess
@@ -45,6 +46,108 @@ def _strip_ansi_codes(text: str) -> str:
     return ansi_escape.sub("", text)
 
 
+@beartype
+@require(lambda repo_path: isinstance(repo_path, Path), "repo_path must be Path")
+@require(lambda targets: isinstance(targets, list), "targets must be list")
+@ensure(lambda result: isinstance(result, tuple) and len(result) == 3, "Must return (list, bool, list)")
+@ensure(
+    lambda result: isinstance(result[0], list) and isinstance(result[1], bool) and isinstance(result[2], list),
+    "Must return (list, bool, list)",
+)
+def _expand_crosshair_targets(repo_path: Path, targets: list[str]) -> tuple[list[str], bool, list[str]]:
+    """
+    Expand directory targets into module names and PYTHONPATH roots, excluding __main__.py.
+    """
+    expanded: list[str] = []
+    excluded_main = False
+    pythonpath_roots: list[str] = []
+    src_root = (repo_path / "src").resolve()
+    lib_root = (repo_path / "lib").resolve()
+
+    for target in targets:
+        target_path = repo_path / target
+        if not target_path.exists():
+            continue
+        if target_path.is_dir():
+            target_root = target_path.resolve()
+            if target_root in (src_root, lib_root):
+                module_root = target_root
+                pythonpath_root = target_root
+            else:
+                module_root = repo_path.resolve()
+                pythonpath_root = repo_path.resolve()
+            pythonpath_root_str = str(pythonpath_root)
+            if pythonpath_root_str not in pythonpath_roots:
+                pythonpath_roots.append(pythonpath_root_str)
+            for py_file in target_root.rglob("*.py"):
+                if py_file.name == "__main__.py":
+                    excluded_main = True
+                    continue
+                module_name = _module_name_from_path(module_root, py_file)
+                if module_name:
+                    expanded.append(module_name)
+        else:
+            if target_path.name == "__main__.py":
+                excluded_main = True
+                continue
+            if target_path.suffix == ".py":
+                file_path = target_path.resolve()
+                if file_path.is_relative_to(src_root):
+                    module_root = src_root
+                    pythonpath_root = src_root
+                elif file_path.is_relative_to(lib_root):
+                    module_root = lib_root
+                    pythonpath_root = lib_root
+                else:
+                    module_root = repo_path.resolve()
+                    pythonpath_root = repo_path.resolve()
+                pythonpath_root_str = str(pythonpath_root)
+                if pythonpath_root_str not in pythonpath_roots:
+                    pythonpath_roots.append(pythonpath_root_str)
+                module_name = _module_name_from_path(module_root, file_path)
+                if module_name:
+                    expanded.append(module_name)
+
+    expanded = sorted(set(expanded))
+    return expanded, excluded_main, pythonpath_roots
+
+
+@beartype
+@require(lambda root: isinstance(root, Path), "root must be Path")
+@require(lambda file_path: isinstance(file_path, Path), "file_path must be Path")
+@ensure(lambda result: result is None or isinstance(result, str), "Must return str or None")
+def _module_name_from_path(root: Path, file_path: Path) -> str | None:
+    """Convert a file path to a module name relative to the root."""
+    try:
+        rel_path = file_path.relative_to(root)
+    except ValueError:
+        return None
+    parts = list(rel_path.parts)
+    if not parts:
+        return None
+    if parts[-1] == "__init__.py":
+        parts = parts[:-1]
+    else:
+        parts[-1] = parts[-1].removesuffix(".py")
+    if not parts or any(part == "" for part in parts):
+        return None
+    return ".".join(parts)
+
+
+@beartype
+@require(lambda pythonpath_roots: isinstance(pythonpath_roots, list), "pythonpath_roots must be list")
+@ensure(lambda result: result is None or isinstance(result, dict), "Must return dict or None")
+def _build_crosshair_env(pythonpath_roots: list[str]) -> dict[str, str] | None:
+    """Build environment with PYTHONPATH for CrossHair module imports."""
+    if not pythonpath_roots:
+        return None
+    env = os.environ.copy()
+    existing = env.get("PYTHONPATH", "")
+    combined = os.pathsep.join(pythonpath_roots + ([existing] if existing else []))
+    env["PYTHONPATH"] = combined
+    return env
+
+
 @beartype
 @require(lambda output: isinstance(output, str), "Output must be string")
 @ensure(lambda result: isinstance(result, dict), "Must return dictionary")
@@ -540,6 +643,7 @@ class ReproChecker:
     @require(lambda tool: isinstance(tool, str) and len(tool) > 0, "Tool must be non-empty string")
     @require(lambda command: isinstance(command, list) and len(command) > 0, "Command must be non-empty list")
     @require(lambda timeout: timeout is None or timeout > 0, "Timeout must be positive if provided")
+    @require(lambda env: env is None or isinstance(env, dict), "env must be dict or None")
     @ensure(lambda result: isinstance(result, CheckResult), "Must return CheckResult")
     @ensure(lambda result: result.duration is None or result.duration >= 0, "Duration must be non-negative")
     def run_check(
@@ -549,6 +653,7 @@ class ReproChecker:
         command: list[str],
         timeout: int | None = None,
         skip_if_missing: bool = True,
+        env: dict[str, str] | None = None,
     ) -> CheckResult:
         """
         Run a single validation check.
@@ -559,6 +664,7 @@ class ReproChecker:
             command: Command to execute
             timeout: Per-check timeout (default: budget / number of checks, must be > 0 if provided)
             skip_if_missing: Skip check if tool not found
+            env: Optional environment variables to pass to the subprocess
 
         Returns:
             CheckResult with status and output
@@ -598,6 +704,7 @@ class ReproChecker:
                 text=True,
                 timeout=check_timeout,
                 check=False,
+                env=env,
             )
 
             result.duration = time.time() - start
@@ -650,9 +757,37 @@ class ReproChecker:
         """
         Run all validation checks.
 
+        Detects the target repository's environment manager and builds appropriate
+        commands. Makes all tools optional with clear messaging when unavailable.
+
         Returns:
             ReproReport with aggregated results
         """
+        from specfact_cli.utils.env_manager import (
+            build_tool_command,
+            check_tool_in_env,
+            detect_env_manager,
+            detect_source_directories,
+        )
+
+        # Detect environment manager for the target repository
+        # Note: Environment detection message is printed in the command layer
+        # (repro.py) before the progress spinner starts to avoid formatting issues
+        env_info = detect_env_manager(self.repo_path)
+
+        # Detect source directories dynamically
+        source_dirs = detect_source_directories(self.repo_path)
+        # Fallback to common patterns if detection found nothing
+        if not source_dirs:
+            # Check for common patterns
+            if (self.repo_path / "src").exists():
+                source_dirs = ["src/"]
+            elif (self.repo_path / "lib").exists():
+                source_dirs = ["lib/"]
+            else:
+                # For external repos, try to find Python packages at root
+                source_dirs = ["."]
+
         # Check if semgrep config exists
         semgrep_config = self.repo_path / "tools" / "semgrep" / "async.yml"
         semgrep_enabled = semgrep_config.exists()
@@ -660,87 +795,98 @@ class ReproChecker:
         # Check if test directories exist
         contracts_tests = self.repo_path / "tests" / "contracts"
         smoke_tests = self.repo_path / "tests" / "smoke"
-        src_dir = self.repo_path / "src"
+        tests_dir = self.repo_path / "tests"
 
-        checks: list[tuple[str, str, list[str], int | None, bool]] = [
-            (
-                "Linting (ruff)",
-                "ruff",
-                ["ruff", "check", "--output-format=full", "src/", "tests/", "tools/"],
-                None,
-                True,
-            ),
-        ]
+        checks: list[tuple[str, str, list[str], int | None, bool, dict[str, str] | None]] = []
 
-        # Add semgrep only if config exists
+        # Linting (ruff) - optional
+        ruff_available, _ = check_tool_in_env(self.repo_path, "ruff", env_info)
+        if ruff_available:
+            ruff_command = ["ruff", "check", "--output-format=full", *source_dirs]
+            if tests_dir.exists():
+                ruff_command.append("tests/")
+            if (self.repo_path / "tools").exists():
+                ruff_command.append("tools/")
+            ruff_command = build_tool_command(env_info, ruff_command)
+            checks.append(("Linting (ruff)", "ruff", ruff_command, None, True, None))
+        else:
+            # Add as skipped check with message
+            checks.append(("Linting (ruff)", "ruff", [], None, True, None))
+
+        # Semgrep - optional, only if config exists
         if semgrep_enabled:
-            semgrep_command = ["semgrep", "--config", str(semgrep_config.relative_to(self.repo_path)), "."]
-            if self.fix:
-                semgrep_command.append("--autofix")
-            checks.append(
-                (
-                    "Async patterns (semgrep)",
-                    "semgrep",
-                    semgrep_command,
-                    30,
-                    True,
-                )
-            )
-
-        checks.extend(
-            [
-                ("Type checking (basedpyright)", "basedpyright", ["basedpyright", "src/", "tools/"], None, True),
-            ]
-        )
-
-        # Add CrossHair only if src/ exists
-        # Exclude common/logger_setup.py from CrossHair analysis due to known signature analysis issues
-        # CrossHair doesn't support --exclude, so we exclude the common directory and add other directories
-        # Use hatch run to ensure CrossHair runs in the correct Python environment with dependencies
-        if src_dir.exists():
-            # Get all subdirectories except common
-            specfact_dirs = [d for d in src_dir.iterdir() if d.is_dir() and d.name != "common"]
-            crosshair_targets = ["src/" + d.name for d in specfact_dirs] + ["tools/"]
-            # Check if hatch is available, otherwise fall back to direct crosshair command
-            hatch_available = shutil.which("hatch") is not None
-            if hatch_available:
-                # Use hatch run to ensure correct Python environment
-                checks.append(
-                    (
-                        "Contract exploration (CrossHair)",
-                        "crosshair",
-                        ["hatch", "run", "python", "-m", "crosshair", "check", *crosshair_targets],
-                        60,
-                        True,
-                    )
-                )
+            semgrep_available, _ = check_tool_in_env(self.repo_path, "semgrep", env_info)
+            if semgrep_available:
+                semgrep_command = ["semgrep", "--config", str(semgrep_config.relative_to(self.repo_path)), "."]
+                if self.fix:
+                    semgrep_command.append("--autofix")
+                semgrep_command = build_tool_command(env_info, semgrep_command)
+                checks.append(("Async patterns (semgrep)", "semgrep", semgrep_command, 30, True, None))
             else:
-                # Fall back to direct crosshair command (may fail if wrong Python environment)
-                checks.append(
-                    (
-                        "Contract exploration (CrossHair)",
-                        "crosshair",
-                        ["crosshair", "check", *crosshair_targets],
-                        60,
-                        True,
+                checks.append(("Async patterns (semgrep)", "semgrep", [], 30, True, None))
+
+        # Type checking (basedpyright) - optional
+        basedpyright_available, _ = check_tool_in_env(self.repo_path, "basedpyright", env_info)
+        if basedpyright_available:
+            basedpyright_command = ["basedpyright", *source_dirs]
+            if (self.repo_path / "tools").exists():
+                basedpyright_command.append("tools/")
+            basedpyright_command = build_tool_command(env_info, basedpyright_command)
+            checks.append(("Type checking (basedpyright)", "basedpyright", basedpyright_command, None, True, None))
+        else:
+            checks.append(("Type checking (basedpyright)", "basedpyright", [], None, True, None))
+
+        # CrossHair - optional, only if source directories exist
+        if source_dirs:
+            crosshair_available, _ = check_tool_in_env(self.repo_path, "crosshair", env_info)
+            if crosshair_available:
+                # Build CrossHair command with detected source directories
+                # For external repos, use all detected source dirs
+                crosshair_targets = source_dirs.copy()
+                if (self.repo_path / "tools").exists():
+                    crosshair_targets.append("tools/")
+
+                expanded_targets, _excluded_main, pythonpath_roots = _expand_crosshair_targets(
+                    self.repo_path, crosshair_targets
+                )
+                if expanded_targets:
+                    crosshair_base = ["python", "-m", "crosshair", "check", *expanded_targets]
+                    crosshair_command = build_tool_command(env_info, crosshair_base)
+                    crosshair_env = _build_crosshair_env(pythonpath_roots)
+                    checks.append(
+                        (
+                            "Contract exploration (CrossHair)",
+                            "crosshair",
+                            crosshair_command,
+                            60,
+                            True,
+                            crosshair_env,
+                        )
                     )
-                )
+                else:
+                    checks.append(("Contract exploration (CrossHair)", "crosshair", [], 60, True, None))
+            else:
+                checks.append(("Contract exploration (CrossHair)", "crosshair", [], 60, True, None))
 
-        # Add property tests only if directory exists
+        # Property tests - optional, only if directory exists
         if contracts_tests.exists():
-            checks.append(
-                (
-                    "Property tests (pytest contracts)",
-                    "pytest",
-                    ["pytest", "tests/contracts/", "-v"],
-                    30,
-                    True,
-                )
-            )
+            pytest_available, _ = check_tool_in_env(self.repo_path, "pytest", env_info)
+            if pytest_available:
+                pytest_command = ["pytest", "tests/contracts/", "-v"]
+                pytest_command = build_tool_command(env_info, pytest_command)
+                checks.append(("Property tests (pytest contracts)", "pytest", pytest_command, 30, True, None))
+            else:
+                checks.append(("Property tests (pytest contracts)", "pytest", [], 30, True, None))
 
-        # Add smoke tests only if directory exists
+        # Smoke tests - optional, only if directory exists
         if smoke_tests.exists():
-            checks.append(("Smoke tests (pytest smoke)", "pytest", ["pytest", "tests/smoke/", "-v"], 30, True))
+            pytest_available, _ = check_tool_in_env(self.repo_path, "pytest", env_info)
+            if pytest_available:
+                pytest_command = ["pytest", "tests/smoke/", "-v"]
+                pytest_command = build_tool_command(env_info, pytest_command)
+                checks.append(("Smoke tests (pytest smoke)", "pytest", pytest_command, 30, True, None))
+            else:
+                checks.append(("Smoke tests (pytest smoke)", "pytest", [], 30, True, None))
 
         for check_args in checks:
             # Check budget before starting
@@ -749,6 +895,20 @@ class ReproChecker:
                 self.report.budget_exceeded = True
                 break
 
+            # Skip checks with empty commands (tool not available)
+            name, tool, command, _timeout, _skip_if_missing, _env = check_args
+            if not command:
+                # Tool not available - create skipped result with helpful message
+                _tool_available, tool_message = check_tool_in_env(self.repo_path, tool, env_info)
+                result = CheckResult(
+                    name=name,
+                    tool=tool,
+                    status=CheckStatus.SKIPPED,
+                    error=tool_message or f"Tool '{tool}' not available",
+                )
+                self.report.add_check(result)
+                continue
+
             # Run check
             result = self.run_check(*check_args)
             self.report.add_check(result)
